@@ -93,12 +93,15 @@ class TestDistributions(unittest.TestCase):
             0.000161214690242696,
         ]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
+            input_lists.append(mass)
             python_results.append(powerlaw(1, 100, -2.3, mass))
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
+            msg = "Error: Value perl: {} Value python: {} for mass, per: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
             self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
 
         # extra test for k = -1
@@ -118,15 +121,18 @@ class TestDistributions(unittest.TestCase):
             6.19974072148769e-06,
         ]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
+            input_lists.append(mass)
             python_results.append(
                 three_part_powerlaw(mass, 0.08, 0.1, 1, 300, -1.3, -2.3, -2.3)
             )
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for mass, per: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
 
         # Extra test:
         # M < M0
@@ -149,13 +155,17 @@ class TestDistributions(unittest.TestCase):
             1.77061658757533e-05,
         ]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
+            input_lists.append(mass)
             python_results.append(Kroupa2001(mass))
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for mass: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
+
         # Extra tests:
         self.assertEqual(
             Kroupa2001(10, newopts={"mmax": 300}),
@@ -176,13 +186,17 @@ class TestDistributions(unittest.TestCase):
             4.02817276824841e-06,
         ]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
+            input_lists.append(mass)
             python_results.append(ktg93(mass))
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for mass: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
+
         # extra test:
         self.assertEqual(
             ktg93(10, newopts={"mmax": 300}),
@@ -235,7 +249,7 @@ class TestDistributions(unittest.TestCase):
         self.assertLess(
             np.abs(imf_chabrier2003(m) - 0.581457346702825),
             self.tolerance,
-            msg="Difference is bigger than the tolerance",
+            msg="Difference is bigger than the tolerance. Input mass = {}".format(m),
         )
 
         # For m = 2
@@ -243,7 +257,7 @@ class TestDistributions(unittest.TestCase):
         self.assertLess(
             np.abs(imf_chabrier2003(m) - 0.581457346702825),
             self.tolerance,
-            msg="Difference is bigger than the tolerance",
+            msg="Difference is bigger than the tolerance. Input mass = {}".format(m),
         )
 
     def test_duquennoy1991(self):
@@ -267,13 +281,16 @@ class TestDistributions(unittest.TestCase):
             0.0134332780385336,
         ]
         python_results = []
+        input_lists = []
 
         for logper in self.logper_list:
+            input_lists.append(logper)
             python_results.append(gaussian(logper, 4.8, 2.3, -2.0, 12.0))
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for logper: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
 
         # Extra test:
         self.assertTrue(
@@ -295,13 +312,16 @@ class TestDistributions(unittest.TestCase):
             0.8388,
         ]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
+            input_lists.append(mass)
             python_results.append(Arenou2010_binary_fraction(mass))
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for mass: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
 
     def test_raghavan2010_binary_fraction(self):
         """
@@ -310,13 +330,16 @@ class TestDistributions(unittest.TestCase):
 
         perl_results = [0.304872297931597, 0.334079955706623, 0.41024, 1, 1, 1]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
+            input_lists.append(mass)
             python_results.append(raghavan2010_binary_fraction(mass))
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for mass: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
 
     def test_Izzard2012_period_distribution(self):
         """
@@ -362,14 +385,18 @@ class TestDistributions(unittest.TestCase):
             0.0221093965810181,
         ]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
             for per in self.per_list:
+                input_lists.append([mass, per])
+
                 python_results.append(Izzard2012_period_distribution(per, mass))
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for mass, per: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
 
     def test_flatsections(self):
         """
@@ -385,15 +412,18 @@ class TestDistributions(unittest.TestCase):
             1.01010101010101,
         ]
         python_results = []
+        input_lists = []
 
         for q in self.q_list:
+            input_lists.append(q)
             python_results.append(
                 flatsections(q, [{"min": 0.01, "max": 1.0, "height": 1.0}])
             )
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
+            msg = "Error: Value perl: {} Value python: {} for q: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
 
     def test_sana12(self):
         """
@@ -619,6 +649,7 @@ class TestDistributions(unittest.TestCase):
             0.066436408359805,
         ]
         python_results = []
+        input_lists = []
 
         for mass in self.mass_list:
             for q in self.q_list:
@@ -628,6 +659,9 @@ class TestDistributions(unittest.TestCase):
                     sep = calc_sep_from_period(mass, mass_2, per)
                     sep_min = calc_sep_from_period(mass, mass_2, 10 ** 0.15)
                     sep_max = calc_sep_from_period(mass, mass_2, 10 ** 5.5)
+
+                    input_lists.append([mass, mass_2, per])
+
                     python_results.append(
                         sana12(
                             mass, mass_2, sep, per, sep_min, sep_max, 0.15, 5.5, -0.55
@@ -636,8 +670,8 @@ class TestDistributions(unittest.TestCase):
 
         # GO over the results and check whether they are equal (within tolerance)
         for i in range(len(python_results)):
-            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance)
-
+            msg = "Error: Value perl: {} Value python: {} for mass, mass2, per: {}".format(python_results[i], perl_results[i], str(input_lists[i]))
+            self.assertLess(np.abs(python_results[i] - perl_results[i]), self.tolerance, msg=msg)
 
 if __name__ == "__main__":
     unittest.main()
