@@ -798,12 +798,12 @@ class test_grid_evolve(unittest.TestCase):
 
         analytics = test_pop.evolve()
 
-        self.assertTrue(isinstance(test_pop.grid_options["ensemble_results"], dict))
-        self.assertNotEqual(test_pop.grid_options["ensemble_results"], {})
+        self.assertTrue(isinstance(test_pop.grid_ensemble_results['ensemble'], dict))
+        self.assertNotEqual(test_pop.grid_ensemble_results['ensemble'], {})
 
-        self.assertIn("number_counts", test_pop.grid_options["ensemble_results"])
+        self.assertIn("number_counts", test_pop.grid_ensemble_results['ensemble'])
         self.assertNotEqual(
-            test_pop.grid_options["ensemble_results"]["number_counts"], {}
+            test_pop.grid_ensemble_results['ensemble']["number_counts"], {}
         )
 
     def test_grid_evolve_2_threads_with_ensemble_comparing_two_methods(self):
@@ -850,7 +850,7 @@ class test_grid_evolve(unittest.TestCase):
         )
 
         analytics_1 = test_pop_1.evolve()
-        ensemble_output_1 = test_pop_1.grid_options["ensemble_results"]
+        ensemble_output_1 = test_pop_1.grid_ensemble_results
 
         # second
         test_pop_2 = Population()
@@ -911,18 +911,17 @@ class test_grid_evolve(unittest.TestCase):
 
                 ensemble_output_2 = merge_dicts(ensemble_output_2, ensemble_json)
 
-        for key in ensemble_output_1["number_counts"]["stellar_type"]["0"]:
+        for key in ensemble_output_1['ensemble']["number_counts"]["stellar_type"]["0"]:
             self.assertIn(key, ensemble_output_2["number_counts"]["stellar_type"]["0"])
 
             # compare values
             self.assertLess(
                 np.abs(
-                    ensemble_output_1["number_counts"]["stellar_type"]["0"][key]
+                    ensemble_output_1['ensemble']["number_counts"]["stellar_type"]["0"][key]
                     - ensemble_output_2["number_counts"]["stellar_type"]["0"][key]
                 ),
                 1e-8,
             )
 
-
 if __name__ == "__main__":
     unittest.main()
