@@ -900,6 +900,21 @@ def flatsections(x: float, opts: dict) -> Union[float, int]:
 # Star formation histories
 ########################################################################
 
+def cosmic_SFH_madau_dickinson2014(z):
+    """
+    Cosmic star formation history distribution from Madau & Dickonson 2014 (https://arxiv.org/pdf/1403.0007.pdf)
+    
+    Args:
+        z: redshift
+    
+    Returns:
+        Cosmic star formation rate in Solarmass year^-1 megaparsec^-3
+    """
+
+    CSFH = 0.015 * ((1+z)**2.7)/(1+(((1+z)/2.9)**5.6))
+
+    return CSFH
+
 ########################################################################
 # Metallicity distributions
 ########################################################################
