@@ -460,8 +460,10 @@ def output_lines(output: str) -> list:
         Iterator over the lines of the binary_c output
     """
 
-    return output.splitlines()
-
+    if output:
+        return output.splitlines()
+    else:
+        return []
 
 def example_parse_output(output: str, selected_header: str) -> dict:
     """
