@@ -30,6 +30,7 @@ grid_options_defaults_dict = {
     "combine_ensemble_with_thread_joining": True,  # Flag on whether to combine everything and return it to the user or if false: write it to data_dir/ensemble_output_{popuation_id}_{thread_id}.json
     # "output_dir":
     "_commandline_input": "",
+    "log_runtime_systems": 0, # whether to log the runtime of the systems (1 file per thread. stored in the tmp_dir)
     ##########################
     # Execution log:
     ##########################
@@ -85,8 +86,6 @@ grid_options_defaults_dict = {
     "_probtot": 0,  # total probability
     "weight": 1.0,  # weighting for the probability
     "repeat": 1,  # number of times to repeat each system (probability is adjusted to be 1/repeat)
-    "results": {},  # dict to store the results. Every process fills this on its own and then it will be joined later
-    "ensemble_results": {},  # Dict to store the ensemble results
     "_start_time_evolution": 0,  # Start time of the grid
     "_end_time_evolution": 0,  # end time of the grid
     "_errors_found": False,  # Flag whether there are any errors from binary_c
@@ -436,7 +435,6 @@ grid_options_descriptions = {
     "_errors_found": "Variable storing a boolean flag whether errors by binary_c are encountered.",
     "_errors_exceeded": "Variable storing a boolean flag whether the amount of errors was higher than the set threshold (failed_systems_threshold). If True, then the commandline arguments of the failing systems will not be stored in the failed_system_log files.",
     "source_file_filename": "Variable containing the source file containing lines of binary_c commandline calls. These all have to start with binary_c.",  # TODO: Expand
-    "results": "Dictionary in which the user can place their results. This dictionary gets merged at the end of a mulitprocessing simulation.",
     "C_auto_logging": "Dictionary containing parameters to be logged by binary_c. The structure of this dictionary is as follows: the key is used as the headline which the user can then catch. The value at that key is a list of binary_c system parameters (like star[0].mass)",
     "C_logging_code": "Variable to store the exact code that is used for the custom_logging. In this way the user can do more complex logging, as well as putting these logging strings in files.",
     "_failed_count": "Variable storing the amount of failed systems.",
@@ -464,7 +462,7 @@ grid_options_descriptions = {
     "repeat": "Factor of how many times a system should be repeated. Consider the evolution splitting binary_c argument for supernovae kick repeating.",  # TODO: make sure this is used.
     "evolution_type": "Variable containing the type of evolution used of the grid. Multiprocessing or linear processing",
     "combine_ensemble_with_thread_joining": "BOolean flag on whether to combine everything and return it to the user or if false: write it to data_dir/ensemble_output_{popuation_id}_{thread_id}.json",
-    "ensemble_results": "Dictinary that stores the ensemble results if combine_ensemble_with_thread_joining==True",
+    "log_runtime_systems": "Whether to log the runtime of the systems . Each systems run by the thread is logged to a file and is stored in the tmp_dir. (1 file per thread). Don't use this if you are planning to run alot of systems. This is mostly for debugging and finding systems that take long to run. Integer, default = 0. if value is 1 then the systems are logged",
 }
 
 #################################
