@@ -39,6 +39,14 @@ int return_version_info(char ** const outstring,
                 char ** const errorstring,
                 size_t * const nbytes);
 
+
+int return_minimum_orbit_for_RLOF(char * argstring,
+                                   long int store_memaddr,
+                                    char ** const buffer,
+                                    char ** const error_buffer,
+                                    size_t * const nbytes);
+
+
 /* =================================================================== */
 /* Functions to handle memory                                          */
 /* =================================================================== */
